@@ -1,12 +1,7 @@
-import ctypes
 import argparse
-import pdb
 import sys
 import win32gui
 import uiautomation as auto
-import wmi
-from selenium import webdriver
-import win32con
 import datetime
 import easygui
 
